@@ -25,7 +25,7 @@
  */
 
 /* 
- * version 1.15.1  12dec2016
+ * version 1.15.6  25feb2020
  */
 
 #include "utils.h"
@@ -49,12 +49,12 @@ SEXP catnetEntropyPairwise(SEXP rSamples, SEXP rPerturbations) {
 	if(!isNull(rPerturbations) && !isMatrix(rPerturbations))
 		error("Perturbations should be a matrix");
 
-	PROTECT(rSamples = AS_INTEGER(rSamples));
-	pSamples = INTEGER(rSamples);
-	if (!pSamples) {
-		UNPROTECT(1); //rSamples
+	if(isNull(rSamples)) {
 		return rvec;
 	}
+	PROTECT(rSamples = AS_INTEGER(rSamples));
+	pSamples = INTEGER(rSamples);
+	
 	dim = GET_DIM(rSamples);
 	numnodes = INTEGER(dim)[0];
 	numsamples = INTEGER(dim)[1];
@@ -136,9 +136,9 @@ SEXP catnetEntropyPairwise(SEXP rSamples, SEXP rPerturbations) {
 
 	psubSamples = 0;
 	pPerturbations = 0;
+	PROTECT(rPerturbations = AS_INTEGER(rPerturbations));
 	if(!isNull(rPerturbations)) {
-		PROTECT(rPerturbations = AS_INTEGER(rPerturbations));
-		pPerturbations = INTEGER(rPerturbations);
+		pPerturbations = INTEGER_POINTER(rPerturbations);
 		psubSamples = (int*)CATNET_MALLOC(numnodes*numsamples*sizeof(int));
 	}
 
@@ -204,9 +204,7 @@ SEXP catnetEntropyPairwise(SEXP rSamples, SEXP rPerturbations) {
 		}
 	}
 
-	UNPROTECT(1); //rSamples
-	if(!isNull(rPerturbations))
-		UNPROTECT(1); //rPerturbations
+	UNPROTECT(2); // rSamples, rPerturbations
 
 	if(psubSamples)
 		CATNET_FREE(psubSamples);
@@ -258,12 +256,12 @@ SEXP catnetEntropyOrder(SEXP rSamples, SEXP rPerturbations) {
 	if(!isNull(rPerturbations) && !isMatrix(rPerturbations))
 		error("Perturbations should be a matrix");
 
-	PROTECT(rSamples = AS_INTEGER(rSamples));
-	pSamples = INTEGER(rSamples);
-	if (!pSamples) {
-		UNPROTECT(1); //rSamples
+	if(isNull(rSamples)) {
 		return rvec;
 	}
+	PROTECT(rSamples = AS_INTEGER(rSamples));
+	pSamples = INTEGER(rSamples);
+	
 	dim = GET_DIM(rSamples);
 	numnodes = INTEGER(dim)[0];
 	numsamples = INTEGER(dim)[1];
@@ -348,9 +346,9 @@ SEXP catnetEntropyOrder(SEXP rSamples, SEXP rPerturbations) {
 
 	psubSamples = 0;
 	pPerturbations = 0;
+	PROTECT(rPerturbations = AS_INTEGER(rPerturbations));
 	if(!isNull(rPerturbations)) {
-		PROTECT(rPerturbations = AS_INTEGER(rPerturbations));
-		pPerturbations = INTEGER(rPerturbations);
+		pPerturbations = INTEGER_POINTER(rPerturbations);
 		psubSamples = (int*)CATNET_MALLOC(numnodes*numsamples*sizeof(int));
 	}
 
@@ -416,9 +414,7 @@ SEXP catnetEntropyOrder(SEXP rSamples, SEXP rPerturbations) {
 		}
 	}
 
-	UNPROTECT(1); //rSamples
-	if(!isNull(rPerturbations))
-		UNPROTECT(1); //rPerturbations
+	UNPROTECT(2); // rSamples, rPerturbations
 
 	if(psubSamples)
 		CATNET_FREE(psubSamples);
@@ -486,13 +482,12 @@ SEXP catnetKLpairwise(SEXP rSamples, SEXP rPerturbations) {
 	if(!isNull(rPerturbations) && !isMatrix(rPerturbations))
 		error("Perturbations should be a matrix");
 
-	PROTECT(rSamples = AS_INTEGER(rSamples));
-	pSamples = INTEGER(rSamples);
-	if (!pSamples) {
-		UNPROTECT(1); //rSamples
+	if(isNull(rSamples)) {
 		return rvec;
 	}
-
+	PROTECT(rSamples = AS_INTEGER(rSamples));
+	pSamples = INTEGER(rSamples);
+	
 	dim = GET_DIM(rSamples);
 	numnodes = INTEGER(dim)[0];
 	numsamples = INTEGER(dim)[1];	
@@ -567,21 +562,21 @@ SEXP catnetKLpairwise(SEXP rSamples, SEXP rPerturbations) {
 	pprobs2 = (double*)CATNET_MALLOC(maxCategories*maxCategories*sizeof(double));
 
 	if (!pprobs1 || !pprobs2) {
+		UNPROTECT(1); //rSamples
 		CATNET_FREE(pNodeNumCats);
 		CATNET_FREE(pNodeCats);
 		if (pprobs1)
 			CATNET_FREE(pprobs1);
 		if (pprobs2)
 			CATNET_FREE(pprobs2);
-		UNPROTECT(1); //rSamples
 		return rvec;
 	}
 
 	pSamplesPert = 0;
 	pPerturbations = 0;
+	PROTECT(rPerturbations = AS_INTEGER(rPerturbations));
 	if(!isNull(rPerturbations)) {
-		PROTECT(rPerturbations = AS_INTEGER(rPerturbations));
-		pPerturbations = INTEGER(rPerturbations);
+		pPerturbations = INTEGER_POINTER(rPerturbations);
 		pSamplesPert = (int*)CATNET_MALLOC(numnodes*numsamples*sizeof(int));
 	}
 
@@ -591,7 +586,7 @@ SEXP catnetKLpairwise(SEXP rSamples, SEXP rPerturbations) {
 		CATNET_FREE(pNodeCats);
 		CATNET_FREE(pprobs1);
 		CATNET_FREE(pprobs2);
-		UNPROTECT(1); //rSamples
+		UNPROTECT(2); // rSamples, rPerturbations
 		return rvec;
 	}
 
@@ -658,9 +653,7 @@ SEXP catnetKLpairwise(SEXP rSamples, SEXP rPerturbations) {
 		}
 	}
 
-	UNPROTECT(1); //rSamples
-	if(!isNull(rPerturbations))
-		UNPROTECT(1); //rPerturbations
+	UNPROTECT(2); // rSamples, rPerturbations
 
 	if(pSamplesPert)
 		CATNET_FREE(pSamplesPert);
@@ -712,13 +705,12 @@ SEXP catnetPearsonPairwise(SEXP rSamples, SEXP rPerturbations) {
 	if(!isNull(rPerturbations) && !isMatrix(rPerturbations))
 		error("Perturbations should be a matrix");
 
-	PROTECT(rSamples = AS_INTEGER(rSamples));
-	pSamples = INTEGER(rSamples);
-	if (!pSamples) {
-		UNPROTECT(1); //rSamples
+	if(isNull(rSamples)) {
 		return rvec;
 	}
-
+	PROTECT(rSamples = AS_INTEGER(rSamples));
+	pSamples = INTEGER(rSamples);
+	
 	dim = GET_DIM(rSamples);
 	numnodes = INTEGER(dim)[0];
 	numsamples = INTEGER(dim)[1];	
@@ -792,21 +784,21 @@ SEXP catnetPearsonPairwise(SEXP rSamples, SEXP rPerturbations) {
 	pprobs1 = (double*)CATNET_MALLOC(maxCategories*maxCategories*sizeof(double));
 	pprobs2 = (double*)CATNET_MALLOC(maxCategories*maxCategories*sizeof(double));
 	if (!pprobs1 || !pprobs2) {
+		UNPROTECT(1); //rSamples
 		CATNET_FREE(pNodeNumCats);
 		CATNET_FREE(pNodeCats);
 		if (pprobs1)
 			CATNET_FREE(pprobs1);
 		if (pprobs2)
 			CATNET_FREE(pprobs2);
-		UNPROTECT(1); //rSamples
 		return rvec;
 	}
 
 	pSamplesPert = 0;
 	pPerturbations = 0;
+	PROTECT(rPerturbations = AS_INTEGER(rPerturbations));
 	if(!isNull(rPerturbations)) {
-		PROTECT(rPerturbations = AS_INTEGER(rPerturbations));
-		pPerturbations = INTEGER(rPerturbations);
+		pPerturbations = INTEGER_POINTER(rPerturbations);
 		pSamplesPert = (int*)CATNET_MALLOC(numnodes*numsamples*sizeof(int));
 	}
 
@@ -816,7 +808,7 @@ SEXP catnetPearsonPairwise(SEXP rSamples, SEXP rPerturbations) {
 		CATNET_FREE(pNodeCats);
 		CATNET_FREE(pprobs1);
 		CATNET_FREE(pprobs2);
-		UNPROTECT(1); //rSamples
+		UNPROTECT(2); //rSamples, rPerturbations
 		return rvec;
 	}
 	
@@ -878,9 +870,7 @@ SEXP catnetPearsonPairwise(SEXP rSamples, SEXP rPerturbations) {
 		}
 	}
 
-	UNPROTECT(1); //rSamples
-	if(!isNull(rPerturbations))
-		UNPROTECT(1); //rPerturbations
+	UNPROTECT(2); //rSamples, rPerturbations
 
 	if(pSamplesPert)
 		CATNET_FREE(pSamplesPert);
@@ -935,13 +925,12 @@ double *catnetPairwiseCondLikelihood(SEXP rSamples, SEXP rPerturbations) {
 	if(!isNull(rPerturbations) && !isMatrix(rPerturbations))
 		error("Perturbations should be a matrix");
 
-	PROTECT(rSamples = AS_INTEGER(rSamples));
-	pRSamples = INTEGER(rSamples);
-	if (!pRSamples) {
-		UNPROTECT(1); //rSamples
+	if(isNull(rSamples)) {
 		return 0;
 	}
-
+	PROTECT(rSamples = AS_INTEGER(rSamples));
+	pRSamples = INTEGER(rSamples);
+	
 	dim = GET_DIM(rSamples);
 	numnodes = INTEGER(dim)[0];
 	numsamples = INTEGER(dim)[1];	
@@ -961,10 +950,13 @@ double *catnetPairwiseCondLikelihood(SEXP rSamples, SEXP rPerturbations) {
 
 	// categoies
 	pNodeNumCats = (int*)CATNET_MALLOC(numnodes*sizeof(int));
-	if (!pNodeNumCats)
+	if (!pNodeNumCats) {
+		CATNET_FREE(pSamples);
 		return 0;
+	}
 	pNodeCats = (int**)CATNET_MALLOC(numnodes*sizeof(int*));
 	if (!pNodeCats) {
+		CATNET_FREE(pSamples);
 		CATNET_FREE(pNodeNumCats);
 		return 0;
 	}
@@ -1009,20 +1001,18 @@ double *catnetPairwiseCondLikelihood(SEXP rSamples, SEXP rPerturbations) {
 
 	pprobs = (double*)CATNET_MALLOC(maxCategories*maxCategories*sizeof(double));
 	if (!pprobs) {
+		CATNET_FREE(pSamples);
 		CATNET_FREE(pNodeNumCats);
 		CATNET_FREE(pNodeCats);
-		if(!isNull(rPerturbations))
-			UNPROTECT(1); //rPerturbations
 		return 0;
 	}
 
 	matPairs = (double*)CATNET_MALLOC(numnodes*numnodes*sizeof(double));
 	if (!matPairs) {
+		CATNET_FREE(pSamples);
 		CATNET_FREE(pNodeNumCats);
 		CATNET_FREE(pNodeCats);
 		CATNET_FREE(pprobs);
-		if(!isNull(rPerturbations))
-			UNPROTECT(1); //rPerturbations
 		return 0;	
 	}
 
@@ -1030,9 +1020,9 @@ double *catnetPairwiseCondLikelihood(SEXP rSamples, SEXP rPerturbations) {
 
 	pSamplesPert = 0;
 	pPerturbations = 0;
+	PROTECT(rPerturbations = AS_INTEGER(rPerturbations));
 	if(!isNull(rPerturbations)) {
-		PROTECT(rPerturbations = AS_INTEGER(rPerturbations));
-		pPerturbations = INTEGER(rPerturbations);
+		pPerturbations = INTEGER_POINTER(rPerturbations);
 		pSamplesPert = (int*)CATNET_MALLOC(numnodes*numsamples*sizeof(int));
 	}
 
@@ -1101,8 +1091,7 @@ double *catnetPairwiseCondLikelihood(SEXP rSamples, SEXP rPerturbations) {
 			 matPairs[nnode1*numnodes + nnode2] = (matPairs[nnode1*numnodes + nnode2] - fmin)*fsum; 
 	}
 
-	if(!isNull(rPerturbations))
-		UNPROTECT(1); //rPerturbations
+	UNPROTECT(1); //rPerturbations
 
 	if(pSamplesPert)
 		CATNET_FREE(pSamplesPert);
@@ -1130,4 +1119,3 @@ double *catnetPairwiseCondLikelihood(SEXP rSamples, SEXP rPerturbations) {
 	return matPairs;
 
 }
-
