@@ -164,7 +164,7 @@ SEXP RCatnetSearch::estimateCatnets(SEXP rSamples, SEXP rPerturbations,
 	if(!isNull(rPerturbations)) {
 		PROTECT(rPerturbations = AS_INTEGER(rPerturbations));
 		pPerturbations = m_pSearchParams->m_pPerturbations;
-		pRperturbations = INTEGER(rPerturbations);
+		pRperturbations = INTEGER_POINTER(rPerturbations);
 		for(j = 0; j < m_numSamples; j++) {
 			for(i = 0; i < m_numNodes; i++) {
 				pPerturbations[j*m_numNodes + i] = pRperturbations[j*m_numNodes + m_pRorder[i] - 1];
